pub struct GenesisConfig {
pub committee: Committee,
pub timestamp: Timestamp,
pub chains: Vec<ChainDescription>,
pub network_name: String,
}Expand description
The initial configuration of a Linera network, defining its genesis state.
Fields
committee: CommitteeThe initial committee of validators.
timestamp: TimestampThe timestamp of the genesis block.
chains: Vec<ChainDescription>The descriptions of the chains created at genesis, the first of which is the admin chain.
network_name: StringThe name of the network.
Implementations
Sourceimpl GenesisConfig
impl GenesisConfig
Sourcepub fn new(
committee: Committee,
timestamp: Timestamp,
network_name: String,
admin_public_key: AccountPublicKey,
admin_balance: Amount,
) -> Self
pub fn new( committee: Committee, timestamp: Timestamp, network_name: String, admin_public_key: AccountPublicKey, admin_balance: Amount, ) -> Self
Creates a GenesisConfig with the first chain being the admin chain.
Sourcepub fn add_root_chain(
&mut self,
public_key: AccountPublicKey,
balance: Amount,
) -> ChainDescription
pub fn add_root_chain( &mut self, public_key: AccountPublicKey, balance: Amount, ) -> ChainDescription
Adds a new root chain with the given public key and balance, and returns its description.
Sourcepub fn admin_chain_description(&self) -> &ChainDescription
pub fn admin_chain_description(&self) -> &ChainDescription
Returns the description of the admin chain.
Sourcepub fn admin_chain_id(&self) -> ChainId
pub fn admin_chain_id(&self) -> ChainId
Returns the ID of the admin chain.
Sourcepub async fn initialize_storage<S>(&self, storage: &mut S) -> Result<(), Error>
pub async fn initialize_storage<S>(&self, storage: &mut S) -> Result<(), Error>
Writes the committee, network description and genesis chains to storage.
Sourcepub fn hash(&self) -> CryptoHash
pub fn hash(&self) -> CryptoHash
Returns the cryptographic hash of this genesis configuration.
Sourcepub fn committee_blob(&self) -> Blob
pub fn committee_blob(&self) -> Blob
Returns the committee serialized as a blob.
Sourcepub fn network_description(&self) -> NetworkDescription
pub fn network_description(&self) -> NetworkDescription
Returns the network description derived from this genesis configuration.
Sourcepub fn new_for_testing<B: StorageBuilder>(builder: &TestBuilder<B>) -> Self
pub fn new_for_testing<B: StorageBuilder>(builder: &TestBuilder<B>) -> Self
Creates a GenesisConfig for testing from a TestBuilder.